"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.decode = decode;
exports.initLicense = initLicense;
exports.initRuntimeSettingsFromString = initRuntimeSettingsFromString;
exports.decodeBase64 = decodeBase64;

var _reactNative = require("react-native");

var _reactNativeVisionCamera = require("react-native-vision-camera");

const LINKING_ERROR = `The package 'vision-camera-dynamsoft-barcode-reader' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';
const VisionCameraDynamsoftBarcodeReader = _reactNative.NativeModules.VisionCameraDynamsoftBarcodeReader ? _reactNative.NativeModules.VisionCameraDynamsoftBarcodeReader : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }

});

const plugin = _reactNativeVisionCamera.VisionCameraProxy.initFrameProcessorPlugin('decode');
/**
 * Detect barcodes from the camera preview
 */


function decode(frame, config) {
  'worklet';

  if (plugin == null) throw new Error('Failed to load Frame Processor Plugin "decode"!');

  if (config) {
    let record = {};

    if (config.isFront != undefined && config.isFront != null) {
      record["isFront"] = config.isFront;
    }

    if (config.rotateImage != undefined && config.rotateImage != null) {
      record["rotateImage"] = config.rotateImage;
    }

    if (config.template) {
      record["template"] = config.template;
    }

    if (config.license) {
      record["license"] = config.license;
    }

    return plugin.call(frame, record);
  } else {
    return plugin.call(frame);
  }
}

/**
 * Init the license of Dynamsoft Barcode Reader
 */
function initLicense(license) {
  return VisionCameraDynamsoftBarcodeReader.initLicense(license);
}
/**
 * Init the runtime settings from a JSON template
 */


function initRuntimeSettingsFromString(template) {
  return VisionCameraDynamsoftBarcodeReader.initRuntimeSettingsFromString(template);
}
/**
 * Detect barcodes from base64
 */


function decodeBase64(base64) {
  return VisionCameraDynamsoftBarcodeReader.decodeBase64(base64);
}
//# sourceMappingURL=index.js.map